@@ -18,10 +18,11 @@
 ###
 
 import logging
-
 from xml.etree import ElementTree as etree
 from xml.parsers import expat
 
+import six
+
 from neutronclient.common import constants
 from neutronclient.common import exceptions as exception
 from neutronclient.openstack.common.gettextutils import _
@@ -67,9 +68,9 @@ class XMLDictSerializer(DictSerializer):
     def __init__(self, metadata=None, xmlns=None):
         """XMLDictSerializer constructor.
 
-        :param metadata: information needed to deserialize xml into
+        :param metadata: information needed to deserialize XML into
                          a dictionary.
-        :param xmlns: XML namespace to include with serialized xml
+        :param xmlns: XML namespace to include with serialized XML
         """
         super(XMLDictSerializer, self).__init__()
         self.metadata = metadata or {}
@@ -93,7 +94,7 @@ class XMLDictSerializer(DictSerializer):
                 root_key = constants.VIRTUAL_ROOT_KEY
                 root_value = None
             else:
-                link_keys = [k for k in data.iterkeys() or []
+                link_keys = [k for k in six.iterkeys(data) or []
                              if k.endswith('_links')]
                 if link_keys:
                     links = data.pop(link_keys[0], None)
@@ -123,7 +124,7 @@ class XMLDictSerializer(DictSerializer):
         return etree.tostring(node, encoding='UTF-8')
 
     #NOTE (ameade): the has_atom should be removed after all of the
-    # xml serializers and view builders have been updated to the current
+    # XML serializers and view builders have been updated to the current
     # spec that required all responses include the xmlns:atom, the has_atom
     # flag is to prevent current tests from breaking
     def _add_xmlns(self, node, used_prefixes, has_atom=False):
@@ -191,7 +192,7 @@ class XMLDictSerializer(DictSerializer):
                 result.set(
                     constants.TYPE_ATTR,
                     constants.TYPE_FLOAT)
-            LOG.debug(_("Data %(data)s type is %(type)s"),
+            LOG.debug("Data %(data)s type is %(type)s",
                       {'data': data,
                        'type': type(data)})
             if isinstance(data, str):
@@ -235,7 +236,7 @@ class XMLDeserializer(TextDeserializer):
     def __init__(self, metadata=None):
         """XMLDeserializer constructor.
 
-        :param metadata: information needed to deserialize xml into
+        :param metadata: information needed to deserialize XML into
                          a dictionary.
         """
         super(XMLDeserializer, self).__init__()
@@ -392,7 +393,6 @@ class Serializer(object):
         """Deserialize a string to a dictionary.
 
         The string must be in the format of a supported MIME type.
-
         """
         return self.get_deserialize_handler(content_type).deserialize(
             datastring)
