@@ -16,6 +16,8 @@
 
 import sys
 
+from mox3 import mox
+
 from neutronclient.common import exceptions
 from neutronclient.neutron.v2_0 import subnet
 from neutronclient.tests.unit import test_cli20
@@ -315,6 +317,118 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
                                    position_names, position_values,
                                    tenant_id='tenantid')
 
+    def test_create_subnet_max_v4_cidr(self):
+        """Create subnet: --gateway gateway netid cidr."""
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = '192.168.0.1/32'
+        gateway = 'gatewayvalue'
+        args = ['--gateway', gateway, netid, cidr]
+        position_names = ['ip_version', 'network_id', 'cidr', 'gateway_ip']
+        position_values = [4, netid, cidr, gateway]
+        self.mox.StubOutWithMock(cmd.log, 'warning')
+        cmd.log.warning(mox.IgnoreArg())
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values)
+        self.mox.VerifyAll()
+        self.mox.UnsetStubs()
+
+    def test_create_subnet_with_ipv6_ra_mode(self):
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = 'prefixvalue'
+        args = ['--tenant_id', 'tenantid',
+                '--ip-version', '6',
+                '--ipv6-ra-mode', 'dhcpv6-stateful',
+                netid, cidr]
+        position_names = ['ip_version', 'ipv6_ra_mode',
+                          'network_id', 'cidr']
+        position_values = [6, 'dhcpv6-stateful', netid, cidr]
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values,
+                                   tenant_id='tenantid')
+
+    def test_create_subnet_with_ipv6_address_mode(self):
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = 'prefixvalue'
+        args = ['--tenant_id', 'tenantid',
+                '--ip-version', '6',
+                '--ipv6-address-mode', 'dhcpv6-stateful',
+                netid, cidr]
+        position_names = ['ip_version', 'ipv6_address_mode',
+                          'network_id', 'cidr']
+        position_values = [6, 'dhcpv6-stateful', netid, cidr]
+
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values,
+                                   tenant_id='tenantid')
+
+    def test_create_subnet_with_ipv6_modes(self):
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = 'prefixvalue'
+        args = ['--tenant_id', 'tenantid',
+                '--ip-version', '6',
+                '--ipv6-address-mode', 'slaac',
+                '--ipv6-ra-mode', 'slaac',
+                netid, cidr]
+        position_names = ['ip_version', 'ipv6_address_mode',
+                          'ipv6_ra_mode', 'network_id', 'cidr']
+        position_values = [6, 'slaac', 'slaac', netid, cidr]
+
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values,
+                                   tenant_id='tenantid')
+
+    def test_create_subnet_with_ipv6_ra_mode_ipv4(self):
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = 'prefixvalue'
+        args = ['--tenant_id', 'tenantid',
+                '--ip-version', '4',
+                '--ipv6-ra-mode', 'slaac',
+                netid, cidr]
+        position_names = ['ip_version', 'ipv6_ra_mode',
+                          'network_id', 'cidr']
+        position_values = [4, None, netid, cidr]
+        self.assertRaises(exceptions.CommandError, self._test_create_resource,
+                          resource, cmd, name, myid, args, position_names,
+                          position_values, tenant_id='tenantid')
+
+    def test_create_subnet_with_ipv6_address_mode_ipv4(self):
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = 'prefixvalue'
+        args = ['--tenant_id', 'tenantid',
+                '--ip-version', '4',
+                '--ipv6-address-mode', 'slaac',
+                netid, cidr]
+        position_names = ['ip_version', 'ipv6_address_mode',
+                          'network_id', 'cidr']
+        position_values = [4, None, netid, cidr]
+        self.assertRaises(exceptions.CommandError, self._test_create_resource,
+                          resource, cmd, name, myid, args, position_names,
+                          position_values, tenant_id='tenantid')
+
     def test_list_subnets_detail(self):
         """List subnets: -D."""
         resources = "subnets"
